package com.sooka.sponest.event.centereventteventcatalogue.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.dahuatech.icc.exception.ClientException;
import com.dahuatech.icc.oauth.http.IccHttpHttpRequest;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.system.api.RemoteDeptService;
import com.ruoyi.system.api.domain.SysDept;
import com.sooka.sponest.event.centereventtdeptevent.domain.CentereventDeptEvent;
import com.sooka.sponest.event.centereventtdeptevent.service.ICentereventDeptEventService;
import com.sooka.sponest.event.centereventteventcatalogue.domain.CentereventTEventcatalogue;
import com.sooka.sponest.event.centereventteventcatalogue.domain.DaHuaEventBO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.dahua.*;
import com.sooka.sponest.event.centereventteventcatalogue.domain.haikang.EventsVo;
import com.sooka.sponest.event.centereventteventcatalogue.domain.haikang.HaiKangEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.domain.sensor.SensorEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.domain.tower.TowerEventVo;
import com.sooka.sponest.event.centereventteventcatalogue.service.AlarmEventService;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICentereventTEventcatalogueService;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import com.sooka.sponest.event.centereventtfirelog.domain.CentereventTFireLog;
import com.sooka.sponest.event.centereventtfirelog.service.ICentereventTFireLogService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTAttach;
import com.sooka.sponest.event.utils.GWHttpUtilsTest65;
import com.sooka.sponest.event.utils.RemoteApiUtil;
import com.sooka.sponest.monitor.api.RemoteMonitorService;
import com.sooka.sponest.monitor.api.domain.CenterdataTAidevicedept;
import com.sooka.sponest.monitor.api.domain.CenterdataTCamera;
import org.apache.commons.collections4.MapUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static com.ruoyi.common.core.utils.DateUtils.YYYY_MM_DD_HH_MM_SS;
import static com.sooka.sponest.event.utils.EventConstants.*;

@Service
public class AlarmEventServiceImpl implements AlarmEventService {

    Logger logger = LoggerFactory.getLogger(AlarmEventServiceImpl.class);

    @Autowired
    private RemoteDataService remoteDataService;

    @Autowired
    private ICentereventTEventcatalogueService centereventTEventcatalogueService;

    @Autowired
    private ICentereventDeptEventService centereventTDeptEventService;

    @Autowired
    private ICentereventTFireLogService centereventTFireLogService;

    @Autowired
    private ICentereventTEventtypeService centereventTEventtypeService;

    @Value("${sooka.dahuaservice.detail}")
    private String detailUrl;

    @Value("${sooka.supermap.datasetUrl}")
    private String datasetUrl;

    static final String ERROR_MSG_CHANNEL = "无法匹配相关设备！通道编号为：{}";

    static final String ERROR_MSG_DEPT = "无法匹配相关部门！摄像头编号为：{}";

    @Transactional
    @Override
    public String insertHaiKangFireEvent(EventsVo eventsVo) {
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(eventsVo.getSrcIndex()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, eventsVo.getSrcIndex());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 事件目录
        String eventName = eventsVo.getData().getAlarm().getEventName();
        String eventDescription = eventsVo.getData().getAlarm().toString();
        String longitude = eventsVo.getData().getAlarm().getLongitude();
        String latitude = eventsVo.getData().getAlarm().getLatitude();
        String reportor = eventsVo.getSrcName();
        Date reportTime = eventsVo.getData().getSendTime();
        String address = eventsVo.getData().getAlarm().getPlaceName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue("1", null, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, null);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        // 附件
        if (StringUtils.isNotBlank(eventsVo.getData().getImageUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getImageUrl());
            tAttach.setBusIndx(BUS_INDEX_1);
            tAttach.setBusSource("HIK_1");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        if (StringUtils.isNotBlank(eventsVo.getData().getVisiblePicUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getVisiblePicUrl());
            tAttach.setBusIndx(BUS_INDEX_1);
            tAttach.setBusSource("HIK_1");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Transactional
    @Override
    public String insertHaiKangCityEvent(HaiKangEventVo haiKangEventVo) {
        EventsVo eventsVo = haiKangEventVo.getEvents()[0];
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(eventsVo.getSrcIndex()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, eventsVo.getSrcIndex());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCode(haiKangEventVo.getEvents()[0].getData().getText()[0].getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", haiKangEventVo.getEvents()[0].getData().getText()[0].getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = centerdataTCamera.getCameraName() + haiKangEventVo.getSendTime() + eventsVo.getData().getText()[0].getAlarmTypeName();
        String eventDescription = eventsVo.toString(centerdataTCamera);
        String longitude = centerdataTCamera.getLongitude();
        String latitude = centerdataTCamera.getLatitude();
        String reportor = eventsVo.getSrcName();
        Date reportTime = haiKangEventVo.getSendTime();
        String address = eventsVo.getData().getText()[0].getOrgName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, null);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(eventsVo.getData().getText()[0].getAlarmPicUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(eventsVo.getData().getText()[0].getAlarmPicUrl());
            tAttach.setBusIndx("bus_indx_city");
            tAttach.setBusSource("HIK_2");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    // 事件目录
    private CentereventTEventcatalogue insertEventCatalogue(CentereventTEventcatalogue centereventTEventcatalogue, CenterdataTCamera centerdataTCamera, Date createTime) {
        //生成uuid
        String eventCode = IdUtils.simpleUUID();
        centereventTEventcatalogue.setId(eventCode);
        centereventTEventcatalogue.setEventCode(eventCode);
        if (null == centereventTEventcatalogue.getReportSource()) {
            centereventTEventcatalogue.setReportSource(REPORTING_SOURCE_1);//reporting_source_1
        }
        centereventTEventcatalogue.setIsUrged(SYS_ISURGE_2);//sys_isurge_2
        centereventTEventcatalogue.setEventStatus("上报");
        centereventTEventcatalogue.setEventStatusValue(FOREST_EVENT_STATUS_1);//forest_event_status_1
        // 自动研判误报，218工程车、222区域入侵、237违章建筑
        if ("218".equals(centereventTEventcatalogue.getEventTypeXl()) || "222".equals(centereventTEventcatalogue.getEventTypeXl()) || "237".equals(centereventTEventcatalogue.getEventTypeXl())) {
            test(centereventTEventcatalogue);
        }
        centereventTEventcatalogue.setCreateBy(centerdataTCamera.getId());
        centereventTEventcatalogue.setCreateName(centerdataTCamera.getCameraName());
        centereventTEventcatalogue.setCreateTime(null == createTime ? DateUtils.getNowDate() : createTime);
        centereventTEventcatalogueService.insertCentereventTEventcatalogue(centereventTEventcatalogue);
        return centereventTEventcatalogue;
    }

    private void test(CentereventTEventcatalogue centereventTEventcatalogue) {
        try {
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_JSON);
            for (String url : datasetUrl.split(";")) {
                JSONObject requestBody = JSONObject.parseObject("{" +
                        "\"getFeatureMode\": \"SPATIAL\"," +
                        "\"datasetNames\": " + url.split("&datasetNames=")[1] + "," +
                        "\"geometry\": {" +
                        "\"id\": 0," +
                        "\"style\": null," +
                        "\"parts\": [1]," +
                        "\"points\": [{" +
                        "\"y\": " + Double.parseDouble(centereventTEventcatalogue.getLatitude()) + "," +
                        "\"x\": " + Double.parseDouble(centereventTEventcatalogue.getLongitude()) +
                        "}]," +
                        "\"type\": \"POINT\"}," +
                        "\"spatialQueryMode\": \"INTERSECT\"" +
                        "}");
                HttpEntity<JSONObject> entity = new HttpEntity<>(requestBody, headers);
                RestTemplate restTemplate = new RestTemplate();
                JSONObject result = restTemplate.postForEntity(url.split("&datasetNames=")[0], entity, JSONObject.class).getBody();
                logger.info(result.toJSONString());
                // {"features":[],"featureUriList":[],"datasetInfos":[],"totalCount":0,"featureCount":0}
                if (result.getLong("totalCount") != 0 && result.getLong("featureCount") != 0) {
                    centereventTEventcatalogue.setEventStatus("误报");
                    centereventTEventcatalogue.setEventStatusValue("forest_event_status_3");
                    break;
                }
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
    }

    // 事件部门
    private void insertEventDept(CentereventTEventcatalogue centereventTEventcatalogue, List<CenterdataTAidevicedept> listDept) {
        listDept.forEach(item -> {
            CentereventDeptEvent centereventTDeptEvent = new CentereventDeptEvent();
            centereventTDeptEvent.setId(IdUtils.fastSimpleUUID());
            centereventTDeptEvent.setEventCode(centereventTEventcatalogue.getEventCode());
            centereventTDeptEvent.setDeptId(item.getMapDeptId());
            centereventTDeptEvent.setDeptName(item.getMapDeptName());
            centereventTDeptEvent.setIsUrged(SYS_ISURGE_2);
            centereventTDeptEvent.setEventStatus("上报");
            centereventTDeptEvent.setEventStatusValue(FOREST_EVENT_STATUS_1);
            centereventTDeptEvent.setDeptHandleType(DEPT_HANDLE_TYPE_2);
            centereventTDeptEvent.setCreateName(centereventTEventcatalogue.getCreateName());
            centereventTDeptEvent.setCreateTime(centereventTEventcatalogue.getCreateTime());
            centereventTDeptEventService.insertCentereventTDeptEvent(centereventTDeptEvent);
        });
    }

    // 事件日志
    private String insertEventLog(CentereventTEventcatalogue centereventTEventcatalogue) {
        CentereventTFireLog centereventTFireLog = new CentereventTFireLog();
        centereventTFireLog.setId(IdUtils.simpleUUID());
        centereventTFireLog.setEventCode(centereventTEventcatalogue.getEventCode());
        centereventTFireLog.setLogContent(centereventTEventcatalogue.getEventName() + System.getProperty("line.separator") + centereventTEventcatalogue.getEventDescription());
        centereventTFireLog.setOperation(BUS_OPER_TYPE_2);
        centereventTFireLog.setOperationType(LOG_OPER_TYPE_3);
        centereventTFireLog.setCreateName(centereventTEventcatalogue.getCreateName());
        centereventTFireLog.setCreateTime(centereventTEventcatalogue.getCreateTime());
        centereventTFireLogService.insertCentereventTFireLog(centereventTFireLog);
        return centereventTFireLog.getId();
    }


    @Transactional
    @Override
    public String insertDaHuaEvent(DaHuaFireEventVO daHuaFireEventVO) {
        Long type = MapUtils.getLong(daHuaFireEventVO.getInfo(), "alarmType");
        // 313：烟雾，5122：热感
        if (type == 313 || type == 5122) {
            return insertFireEvent(daHuaFireEventVO);
        } else if (type == 302 || type == 303 || type == 962 || type == 963 || type == 964 || type == 965) {
            // 302：绊线入侵，303：区域入侵 ，962：人穿越警戒线，963：机动车穿越警戒线，964：人穿越区域，965：机动车穿越区域
            return insertBayonetEvent(daHuaFireEventVO);
        }
        return "";
    }

    public String insertFireEvent(DaHuaFireEventVO daHuaFireEventVO) {
        InfoVO infoVO = JSONObject.parseObject(JSON.toJSONString(daHuaFireEventVO.getInfo()), InfoVO.class);
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(infoVO.getChannelSn()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, infoVO.getChannelSn());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 事件目录
        //四平市双辽市卧虎镇贺家村热感应 + 2024-01-05 10:32:54 + 火情报警
        String eventName = infoVO.getChannelName() + infoVO.getAlarmDateStr() + infoVO.getAlarmTypeName();
        String eventDescription = infoVO.toString(centerdataTCamera);
        String longitude = StringUtils.isEmpty(infoVO.getFirePoint()) ? centerdataTCamera.getLongitude() : infoVO.getFirePoint()[0].getGpsX();
        String latitude = StringUtils.isEmpty(infoVO.getFirePoint()) ? centerdataTCamera.getLatitude() : infoVO.getFirePoint()[0].getGpsY();
        String reportor = infoVO.getDeviceName();
        Date reportTime = DateUtils.timestampToTime(infoVO.getAlarmDate());
        String address = centerdataTCamera.getCameraRegion();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue("1", null, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, daHuaFireEventVO.getCreateTime());
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(infoVO.getPicture())) {
            String[] pictures = infoVO.getPicture().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(picture);
                tAttach.setBusIndx(BUS_INDEX_1);
                tAttach.setBusSource("DH_1");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        return centereventTEventcatalogue.getEventCode();
    }

    private String insertBayonetEvent(DaHuaFireEventVO daHuaFireEventVO) {
        BayonetInfoVO infoVO = JSONObject.parseObject(JSON.toJSONString(daHuaFireEventVO.getInfo()), BayonetInfoVO.class);
        // 验证是否配置摄像头
        List<CenterdataTCamera> centerdataTCameras = SpringUtils.getBean(RemoteMonitorService.class).selectCameraByDepIdGong(new CenterdataTCamera(null, infoVO.getDeviceName())).getData();
        if (StringUtils.isEmpty(centerdataTCameras) || 1 != centerdataTCameras.size()) {
            logger.info("无法匹配相关设备！摄像头为：{}", infoVO.getDeviceName());
            return "";
        }
        // 验证是否配置指挥中心
        CenterdataTCamera centerdataTCamera = centerdataTCameras.get(0);
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCode(infoVO.getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", infoVO.getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = infoVO.getChannelName() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, new Date(infoVO.getAlarmDate() * 1000)) + centereventTEventtype.getEventTypeName();
        String eventDescription = infoVO.toString(centerdataTCamera);
        String longitude = centerdataTCamera.getLongitude();
        String latitude = centerdataTCamera.getLatitude();
        String reportor = centerdataTCamera.getCameraName();
        Date reportTime = DateUtils.timestampToTime(infoVO.getAlarmDate() * 1000);
        String address = centerdataTCamera.getCameraRegion();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, daHuaFireEventVO.getCreateTime());
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(infoVO.getAlarmPicture())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(infoVO.getAlarmPicture());
            tAttach.setBusIndx(BUS_INDEX_2);
            tAttach.setBusSource("DH_1");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Override
    public String updateFireEventImage(DaHuaEventBO eventBO) throws ClientException {
        // 通过eventCode查询详情
        CentereventTEventcatalogue centereventTEventcatalogue = centereventTEventcatalogueService.selectCentereventTEventcatalogueById(eventBO.getEventCode());
        // 确认为   火情事件   并且   状态为上报
        if ("1".equals(centereventTEventcatalogue.getEventType()) && "forest_event_status_1".equals(centereventTEventcatalogue.getEventStatusValue())) {
            // 按照指定格式拼接路径
            String url = "alarmCode=" + RemoteApiUtil.encodeUrl(eventBO.getAlarmCode()) + "&dbType=" + RemoteApiUtil.encodeUrl(eventBO.getDbType()) + "&alarmDate=" + RemoteApiUtil.encodeUrl(eventBO.getAlarmDate());
            // 创建请求实体 并 发送请求
            String prBody = new IccHttpHttpRequest(detailUrl + url)
                    // 设置token
                    .header("Authorization", "bearer " + RemoteApiUtil.getInstance().getToken())
                    // 客户端模式，设置请求头 # clientKey & clientValue 在请求大华接口时，以客户端模式请求必填。客户端模式无法请求：考勤，客流，信息发布，报警主机等模块
                    .header("User-Id", "1")
                    // 发送请求
                    .execute();
            // 处理响应结果
            JSONObject responseData = JSON.parseObject(prBody);
            if (responseData.getBoolean("success")) {
                ArrayList<String> pictures = responseData.getJSONObject("data").getObject("pictures", ArrayList.class);
                if (pictures.isEmpty()) {
                    logger.error("获取的图片集合为空-----请求结果：{}", prBody);
                    return "暂无图片, 请稍后重试";
                }
                // 添加新附件
                List<CenterdataTAttach> attachList = new ArrayList<>();
                for (String picture : pictures) {
                    CenterdataTAttach tAttach = new CenterdataTAttach();
                    tAttach.setBusId(eventBO.getLogId());
                    tAttach.setAttachPath(picture);
                    tAttach.setBusIndx(BUS_INDEX_1);
                    tAttach.setBusSource("DH_1");
                    tAttach.setFileType(FILE_TYPE_1);
                    attachList.add(tAttach);
                }
                return remoteDataService.delAndInsertBatch(JSON.toJSONString(attachList)).getMsg();
            }
            logger.error("请求远端异常-----请求结果：{}", prBody);
            return "请求异常, 请联系管理员";
        }
        return "请刷新后重试";
    }

    @Transactional
    @Override
    public String insertDaHuaOtherEvent(DaHuaOtherEventVO daHuaOtherEventVO) {
        // 验证是否配置摄像头通道
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getInfoByChannelCode(daHuaOtherEventVO.getChannelSn()).getData();
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info(ERROR_MSG_CHANNEL, daHuaOtherEventVO.getChannelSn());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, centerdataTCamera.getCameraCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCode(daHuaOtherEventVO.getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", daHuaOtherEventVO.getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = centerdataTCamera.getCameraName() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, DateUtils.timestampToTime(daHuaOtherEventVO.getOccurrenceTime())) + centereventTEventtype.getEventTypeName();
        String eventDescription = daHuaOtherEventVO.toString();
        String longitude = daHuaOtherEventVO.getLongitude();
        String latitude = daHuaOtherEventVO.getLatitude();
        String reportor = centerdataTCamera.getCameraName();
        Date reportTime = DateUtils.timestampToTime(daHuaOtherEventVO.getOccurrenceTime());
        String address = daHuaOtherEventVO.getAddress();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, daHuaOtherEventVO.getCreateTime());
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(daHuaOtherEventVO.getImgList())) {
            List<PictureVO> pictures = JSON.parseArray(daHuaOtherEventVO.getImgList(), PictureVO.class);
            for (PictureVO picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(picture.getImgUrl().substring(picture.getImgUrl().indexOf("/image")));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("DH_2");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Transactional
    @Override
    public String insertTowerEvent(TowerEventVo towerEventVo) {
        // 验证是否配置摄像头
        CenterdataTCamera centerdataTCamera = SpringUtils.getBean(RemoteMonitorService.class).getCameraByChinaTowerDeviceCode(towerEventVo.getDeviceCode());
        if (StringUtils.isNull(centerdataTCamera)) {
            logger.info("无法匹配相关设备！铁塔摄像头为：{}", towerEventVo.getDeviceCode());
            return "";
        }
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(centerdataTCamera.getId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, towerEventVo.getDeviceCode());
            return "";
        }
        // 验证事件类型是否配置对应报文码值--只能从数据库配
        CentereventTEventtype centereventTEventtype = centereventTEventtypeService.selectCentereventTEventtypeByCodeTower(towerEventVo.getAlarmType());
        if (StringUtils.isNull(centereventTEventtype)) {
            logger.info("无法匹配相关事件！报文码值为：{}", towerEventVo.getAlarmType());
            return "";
        }
        // 事件目录
        String eventType = centereventTEventtype.getParentId();
        String eventTypeXl = centereventTEventtype.getId();
        String eventName = towerEventVo.getDeviceName() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, towerEventVo.getAlarmTime()) + centereventTEventtype.getEventTypeName();
        String eventDescription = towerEventVo.toString();
        String longitude = towerEventVo.getEventLongitude();
        String latitude = towerEventVo.getEventLatitude();
        String reportor = towerEventVo.getDeviceName();
        Date reportTime = towerEventVo.getAlarmTime();
        String address = towerEventVo.getAddress();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(eventType, eventTypeXl, eventName, eventDescription, longitude, latitude, reportor, reportTime, address);
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, null);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        String orderCode = SpringUtils.getBean(RemoteMonitorService.class).getOrderCodeByChinaTowerDeviceCode(towerEventVo.getDeviceCode());
        if (StringUtils.isNotBlank(towerEventVo.getOriginalPictureUrl())) {
            String[] pictures = towerEventVo.getOriginalPictureUrl().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(picture, orderCode));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("TT_1");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        if (StringUtils.isNotBlank(towerEventVo.getAlarmPictureUrl())) {
            String[] pictures = towerEventVo.getAlarmPictureUrl().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(picture, orderCode));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("TT_1");
                tAttach.setFileType(FILE_TYPE_1);
                remoteDataService.insertAttach(tAttach);
            }
        }
        if (StringUtils.isNotBlank(towerEventVo.getAlarmVideoUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(towerEventVo.getAlarmVideoUrl(), orderCode));
            tAttach.setBusIndx(BUS_INDEX_2);
            tAttach.setBusSource("TT_1");
            tAttach.setFileType(FILE_TYPE_2);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode();
    }

    @Override
    public String updateFireEventImage(TowerEventVo towerEventVo, String logId) {
        List<CenterdataTAttach> attachList = new ArrayList<>();
        String orderCode = SpringUtils.getBean(RemoteMonitorService.class).getOrderCodeByChinaTowerDeviceCode(towerEventVo.getDeviceCode());
        if (StringUtils.isNotBlank(towerEventVo.getOriginalPictureUrl())) {
            String[] pictures = towerEventVo.getOriginalPictureUrl().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(picture, orderCode));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("TT_1");
                tAttach.setFileType(FILE_TYPE_1);
                attachList.add(tAttach);
            }
        }
        if (StringUtils.isNotBlank(towerEventVo.getAlarmPictureUrl())) {
            String[] pictures = towerEventVo.getAlarmPictureUrl().split(",");
            for (String picture : pictures) {
                CenterdataTAttach tAttach = new CenterdataTAttach();
                tAttach.setBusId(logId);
                tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(picture, orderCode));
                tAttach.setBusIndx(BUS_INDEX_2);
                tAttach.setBusSource("TT_1");
                tAttach.setFileType(FILE_TYPE_1);
                attachList.add(tAttach);
            }
        }
        if (StringUtils.isNotBlank(towerEventVo.getAlarmVideoUrl())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(GWHttpUtilsTest65.encrypt(towerEventVo.getAlarmVideoUrl(), orderCode));
            tAttach.setBusIndx(BUS_INDEX_2);
            tAttach.setBusSource("TT_1");
            tAttach.setFileType(FILE_TYPE_2);
            attachList.add(tAttach);
        }
        return remoteDataService.delAndInsertBatch(JSON.toJSONString(attachList)).getMsg();
    }

    @Transactional
    @Override
    public String insertSensorEvent(SensorEventVo sensorEventVo) {
        // 验证是否配置指挥中心
        List<CenterdataTAidevicedept> listDept = SpringUtils.getBean(RemoteMonitorService.class).listForCommandCenter(sensorEventVo.getSensorId(), "1", "1").getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info(ERROR_MSG_DEPT, sensorEventVo.getReportor());
            return "";
        }
        // 事件目录
        CentereventTEventtype eventtype = centereventTEventtypeService.selectCentereventTEventtypeById(sensorEventVo.getEventTypeXl());
        String eventName = sensorEventVo.getReportor() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, sensorEventVo.getReportTime()) + eventtype.getEventTypeName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(sensorEventVo.getEventType(), sensorEventVo.getEventTypeXl(), eventName, sensorEventVo.getEventDescription(), sensorEventVo.getLongitude(), sensorEventVo.getLatitude(), sensorEventVo.getReportor(), sensorEventVo.getReportTime(), sensorEventVo.getAddress());
        centereventTEventcatalogue.setReportSource(REPORTING_SOURCE_4);
        CenterdataTCamera centerdataTCamera = new CenterdataTCamera(sensorEventVo.getSensorId(), sensorEventVo.getReportor());
        centereventTEventcatalogue = this.insertEventCatalogue(centereventTEventcatalogue, centerdataTCamera, null);
        // 事件部门
        this.insertEventDept(centereventTEventcatalogue, listDept);
        // 事件日志
        String logId = this.insertEventLog(centereventTEventcatalogue);
        if (StringUtils.isNotBlank(sensorEventVo.getPicture())) {
            CenterdataTAttach tAttach = new CenterdataTAttach();
            tAttach.setBusId(logId);
            tAttach.setAttachPath(sensorEventVo.getPicture());
            tAttach.setBusIndx(BUS_INDEX_3);
            tAttach.setBusSource("SENSOR");
            tAttach.setFileType(FILE_TYPE_1);
            remoteDataService.insertAttach(tAttach);
        }
        return centereventTEventcatalogue.getEventCode() + "_" + eventtype.getEventTypeName();
    }

    @Transactional
    @Override
    public String insertHousingConstructionEvent(SensorEventVo sensorEventVo) {
        // 验证是否配置市级住建局
        SysDept sysDept = new SysDept();
        sysDept.setDeptId(Long.valueOf(SI_PING));
        sysDept.setDeptType(sensorEventVo.getDeptType());// 住建：sys_dept_type_31，执法：
        List<SysDept> listDept = SpringUtils.getBean(RemoteDeptService.class).getDeptsByDeptType(sysDept).getData();
        if (StringUtils.isEmpty(listDept)) {
            logger.info("无法匹配相关部门！");
            return "";
        }
        // 事件目录
        CentereventTEventtype eventtype = centereventTEventtypeService.selectCentereventTEventtypeById(sensorEventVo.getEventTypeXl());
        String eventName = sensorEventVo.getReportor() + DateUtils.parseDateToStr(YYYY_MM_DD_HH_MM_SS, sensorEventVo.getReportTime()) + eventtype.getEventTypeName();
        CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue(sensorEventVo.getEventType(), sensorEventVo.getEventTypeXl(), eventName, sensorEventVo.getEventDescription(), sensorEventVo.getLongitude(), sensorEventVo.getLatitude(), sensorEventVo.getReportor(), sensorEventVo.getReportTime(), sensorEventVo.getAddress());
        centereventTEventcatalogue.setId(IdUtils.simpleUUID());
        centereventTEventcatalogue.setEventCode(centereventTEventcatalogue.getId());
        centereventTEventcatalogue.setReportSource(REPORTING_SOURCE_5);
        centereventTEventcatalogue.setIsUrged(SYS_ISURGE_2);//sys_isurge_2
        centereventTEventcatalogue.setEventStatus("归档");
        centereventTEventcatalogue.setEventStatusValue(FOREST_EVENT_STATUS_6);//forest_event_status_6
        if ("sys_dept_type_31".equals(sensorEventVo.getDeptType())) {
            centereventTEventcatalogue.setDeptId(Long.parseLong(sensorEventVo.getSensorId()));
            centereventTEventcatalogue.setDeptName(sensorEventVo.getReportor());
        } else {
            centereventTEventcatalogue.setDeptId(listDept.get(0).getDeptId());
            centereventTEventcatalogue.setDeptName(listDept.get(0).getDeptName());
        }
        centereventTEventcatalogue.setCreateBy(sensorEventVo.getSensorId());
        centereventTEventcatalogue.setCreateName(sensorEventVo.getReportor());
        centereventTEventcatalogue.setCreateTime(DateUtils.getNowDate());
        centereventTEventcatalogueService.insertCentereventTEventcatalogue(centereventTEventcatalogue);
        // 事件部门
        listDept.forEach(item -> {
            CentereventDeptEvent centereventTDeptEvent = new CentereventDeptEvent();
            centereventTDeptEvent.setId(IdUtils.fastSimpleUUID());
            centereventTDeptEvent.setEventCode(centereventTEventcatalogue.getEventCode());
            centereventTDeptEvent.setDeptId(item.getDeptId());
            centereventTDeptEvent.setDeptName(item.getDeptName());
            centereventTDeptEvent.setIsUrged(SYS_ISURGE_2);
            centereventTDeptEvent.setEventStatus("归档");
            centereventTDeptEvent.setEventStatusValue(FOREST_EVENT_STATUS_6);
            centereventTDeptEvent.setDeptHandleType(DEPT_HANDLE_TYPE_3);
            centereventTDeptEvent.setCreateName(centereventTEventcatalogue.getCreateName());
            centereventTDeptEvent.setCreateTime(centereventTEventcatalogue.getCreateTime());
            centereventTDeptEventService.insertCentereventTDeptEvent(centereventTDeptEvent);
        });
        // 事件日志
        this.insertEventLog(centereventTEventcatalogue);
        return centereventTEventcatalogue.getEventCode() + "_" + eventtype.getEventTypeName();
    }
}
